summaryrefslogtreecommitdiffstats
path: root/libkdegames/highscore/khighscore.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/highscore/khighscore.h')
-rw-r--r--libkdegames/highscore/khighscore.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/libkdegames/highscore/khighscore.h b/libkdegames/highscore/khighscore.h
index b1e3d25f..42c9fcda 100644
--- a/libkdegames/highscore/khighscore.h
+++ b/libkdegames/highscore/khighscore.h
@@ -23,8 +23,8 @@
#ifndef __KHIGHSCORE_H__
#define __KHIGHSCORE_H__
-#include <qstring.h>
-#include <qobject.h>
+#include <tqstring.h>
+#include <tqobject.h>
#include <kdemacros.h>
class KConfig;
class KFileLock;
@@ -67,7 +67,7 @@ class KHighscorePrivate;
* single player, so the "best times" of a player. To write highscores for a
* specific player in a specific level you will have to use a more complex way:
* \code
- * QString group = QString("%1_%2").arg(player).arg(level);
+ * TQString group = TQString("%1_%2").arg(player).arg(level);
* table->setGroup(group);
* writeHighscore(table, player, level);
* \endcode
@@ -76,7 +76,7 @@ class KHighscorePrivate;
* don't use i18n() for the keys or groups! Here is the code to read the above
* written entry:
* \code
- * QString firstName = highscore->readEntry(0, "name");
+ * TQString firstName = highscore->readEntry(0, "name");
* \endcode
* Easy, what?
* @author Andreas Beckermann <b_mann@gmx.de>
@@ -89,7 +89,7 @@ public:
* Constructor. The highscore file is forced to be local to support
* games using the old behaviour.
*/
- KHighscore(QObject* parent = 0);
+ KHighscore(TQObject* parent = 0);
/**
* Constructor.
@@ -100,7 +100,7 @@ public:
* @param parent parent widget for this widget
* @since 3.2
*/
- KHighscore(bool forceLocal, QObject *parent);
+ KHighscore(bool forceLocal, TQObject *parent);
/**
* Read the current state of the highscore file. Remember that when
@@ -137,7 +137,7 @@ public:
* @return false on error or if the config file is locked by another
* process. In such case, the config stays read-only.
*/
- bool lockForWriting(QWidget *widget = 0);
+ bool lockForWriting(TQWidget *widget = 0);
/**
* Effectively write and unlock the system-wide highscore file
@@ -167,20 +167,20 @@ public:
* are prefixed with the entry number
* @param value The value of this entry
**/
- void writeEntry(int entry, const QString& key, const QString& value);
+ void writeEntry(int entry, const TQString& key, const TQString& value);
/**
* This is an overloaded member function, provided for convenience.
* It differs from the above function only in what argument(s) it accepts.
**/
- void writeEntry(int entry, const QString& key, int value);
+ void writeEntry(int entry, const TQString& key, int value);
/**
* This is an overloaded member function, provided for convenience.
* It differs from the above function only in what argument(s) it accepts.
* See KConfigBase documentation for allowed QVariant::Type.
**/
- void writeEntry(int entry, const QString& key, const QVariant &value);
+ void writeEntry(int entry, const TQString& key, const TQVariant &value);
/**
* Reads an entry from the highscore table.
@@ -193,7 +193,7 @@ public:
* @return The value of this entry+key pair or pDefault if the entry+key
* pair doesn't exist
**/
- QString readEntry(int entry, const QString& key, const QString& pDefault = QString::null) const;
+ TQString readEntry(int entry, const TQString& key, const TQString& pDefault = TQString::null) const;
/**
* Read a numeric value.
@@ -206,22 +206,22 @@ public:
* @return The value of this entry+key pair or pDefault if the entry+key
* pair doesn't exist
**/
- int readNumEntry(int entry, const QString& key, int pDefault = -1) const;
+ int readNumEntry(int entry, const TQString& key, int pDefault = -1) const;
/**
* Read a QVariant entry.
* See KConfigBase documentation for allowed QVariant::Type.
*
* @return the value of this entry+key pair or pDefault if the entry+key
* pair doesn't exist or
*/
- QVariant readPropertyEntry(int entry, const QString &key, const QVariant &pDefault) const;
+ TQVariant readPropertyEntry(int entry, const TQString &key, const TQVariant &pDefault) const;
/**
* @return True if the highscore table conatins the entry/key pair,
* otherwise false
**/
- bool hasEntry(int entry, const QString& key) const;
+ bool hasEntry(int entry, const TQString& key) const;
/**
* Reads a list of entries from the highscore table starting at 1 until
@@ -240,7 +240,7 @@ public:
* 20 entries. If lastEntry is <= 0 then rading is only stopped when when an
* entry does not exist.
**/
- QStringList readList(const QString& key, int lastEntry = 20) const;
+ TQStringList readList(const TQString& key, int lastEntry = 20) const;
/**
* Writes a list of entries to the highscore table.
@@ -253,7 +253,7 @@ public:
* are prefixed with the entry number
* @param list The list of values
**/
- void writeList(const QString& key, const QStringList& list);
+ void writeList(const TQString& key, const TQStringList& list);
/**
* @return Whether a highscore table exists. You can use this
@@ -273,24 +273,24 @@ public:
* Set the new highscore group. The group is being prefixed with
* "KHighscore_" in the table.
* @param groupname The new groupname. E.g. use "easy" for the easy
* level of your game. If you use QString::null (the default) the
* default group is used.
**/
- void setHighscoreGroup(const QString& groupname = QString::null);
+ void setHighscoreGroup(const TQString& groupname = TQString::null);
/**
* @return The currently used group. This doesn't contain the prefix
* ("KHighscore_") but the same as setHighscoreGroup uses. The
* default is QString::null
**/
- const QString& highscoreGroup() const;
+ const TQString& highscoreGroup() const;
protected:
/**
* @return A groupname to be used in KConfig. Used internally to
* prefix the value from highscoreGroup() with "KHighscore_"
**/
- QString group() const;
+ TQString group() const;
/**
* @return A pointer to the KConfig object to be used. This is
@@ -167,20 +167,20 @@ public:
* This is an overloaded member function, provided for convenience.
* It differs from the above function only in what argument(s) it accepts.
- * See KConfigBase documentation for allowed QVariant::Type.
+ * See KConfigBase documentation for allowed TQVariant::Type.
**/
@@ -206,22 +206,22 @@ public:
/**
- * Read a QVariant entry.
- * See KConfigBase documentation for allowed QVariant::Type.
+ * Read a TQVariant entry.
+ * See KConfigBase documentation for allowed TQVariant::Type.
*
* @return the value of this entry+key pair or pDefault if the entry+key
@@ -273,24 +273,24 @@ public:
* "KHighscore_" in the table.
* @param groupname The new groupname. E.g. use "easy" for the easy
- * level of your game. If you use QString::null (the default) the
+ * level of your game. If you use TQString::null (the default) the
* default group is used.
**/
@@ -273,24 +273,24 @@ public:
* @return The currently used group. This doesn't contain the prefix
* ("KHighscore_") but the same as setHighscoreGroup uses. The
- * default is QString::null
+ * default is TQString::null
**/